# -- Logging
MAX_LOGFILE_SIZE = 1048576 * 5
MAX_LOGFILES = 30
LOGFILE = '/var/log/infiniguard_api/infiniguard_api.log'
CLI_OUTPUT_DIR = '../src/infiniguard_api/tst/cli_output'
HEADER_USER = b'X-Infinidat-User-Role'
READ_ONLY_ROLE = '[READ_ONLY]'
ADMIN_ROLE = '[ADMIN]'
INFINIDAT_ROLE = '[INFINIDAT]'
TECHNICIAN_ROLE = '[TECHNICIAN]'
